@@ -9,8 +9,7 @@ class Checker(Component):
 
     # INSTAGRAM FUNCTIONS
     # LOGIN PROCEDURE
-    @Component._manage_driver(login=False)
-    def _check_status(self: 'InstaClient'):
+    def check_status(self: 'InstaClient') -> bool:
         """
         Check if account is currently logged in. Returns True if account is logged in. Sets the `instaclient.logged_in` variable accordingly.
         Returns False if the driver is not open yet - even if the Instagram credentials (`username` and `password`) are correct.
@@ -28,8 +27,8 @@ class Checker(Component):
         pass """
 
 
-    @Component._manage_driver(login=False)
-    def _is_valid_user(self:'InstaClient', user:str):
+    @Component._driver_required
+    def is_valid_user(self:'InstaClient', user:str) -> bool:
         """
         _is_valid_user Checks if a given username is a valid Instagram user.
 
@@ -46,7 +45,7 @@ class Checker(Component):
             bool: True if the user is valid
         """
         LOGGER.debug('INSTACLIENT: Checking user vadility')
-        profile:Profile = self._scrape_profile(user)
+        profile:Profile = self.get_profile(user)
         if not profile:
             if ClientUrls.LOGIN_URL in self.driver.current_url:
                 raise NotLoggedInError()
@@ -56,7 +55,7 @@ class Checker(Component):
         return True
 
 
-    @Component._manage_driver(login=False)
+    @Component._driver_required
     def _is_valid_page(self:'InstaClient', url:str=None):
         current = self.driver.current_url
         if url:
