@@ -11,8 +11,8 @@ class Interactions(Navigator):
     END_PAGE_SCROLL=4
     PAGE_DOWN_SCROLL=5
     # FOLLOW PROCEDURE
-    @Component._manage_driver()
-    def _follow_user(self, user:str, nav_to_user:bool=True):
+    @Component._login_required
+    def follow_user(self, user:str, nav_to_user:bool=True):
         """
         _follow_user follows the instagram user that matches the username in the `user` attribute.
         If the target account is private, a follow request will be sent to such user and a `PrivateAccountError` will be raised.
@@ -26,7 +26,7 @@ class Interactions(Navigator):
         """
         # Check User Vadility
         try:
-            result = self._is_valid_user(user)
+            result = self.is_valid_user(user)
             LOGGER.debug('INSTACLIENT: User <{}> is valid'.format(user))
             private = False
         # User is private
@@ -51,8 +51,8 @@ class Interactions(Navigator):
             raise FollowRequestSentError(user)
 
     
-    @Component._manage_driver()
-    def _unfollow_user(self, user:str, nav_to_user=True, check_user=True):
+    @Component._login_required
+    def unfollow_user(self, user:str, nav_to_user=True, check_user=True):
         """
         Unfollows a given user.
 
@@ -67,7 +67,7 @@ class Interactions(Navigator):
         
         if check_user:
             try:
-                self._is_valid_user(user)
+                self.is_valid_user(user)
             except PrivateAccountError:
                 pass
             LOGGER.debug('INSTACLIENT: User <{}> is valid'.format(user))
@@ -89,8 +89,8 @@ class Interactions(Navigator):
             LOGGER.debug(f'Cancelled Follow Request for user <{user}>')
 
     
-    @Component._manage_driver()
-    def _like_latest_posts(self, user:str, n_posts:int, like:bool=True):
+    @Component._login_required
+    def like_user_posts(self, user:str, n_posts:int, like:bool=True):
         """
         Likes a number of a users latest posts, specified by n_posts.
 
@@ -122,8 +122,8 @@ class Interactions(Navigator):
             self.driver.find_elements_by_class_name('ckWGn')[0].click()
 
 
-    @Component._manage_driver()
-    def _send_dm(self:'InstaClient', user:str, message:str):
+    @Component._login_required
+    def send_dm(self:'InstaClient', user:str, message:str):
         """
         Send an Instagram Direct Message to a user. 
 
@@ -151,8 +151,8 @@ class Interactions(Navigator):
 
 
     # ENGAGEMENT PROCEDURES
-    @Component._manage_driver()
-    def _scroll(self, mode=PAGE_DOWN_SCROLL, size=500, times=1, interval=3):
+    @Component._login_required
+    def scroll(self, mode=PAGE_DOWN_SCROLL, size:int=500, times:int=1, interval:int=3):
         """
         Scrolls to the bottom of a users page to load all of their media
 
@@ -178,15 +178,15 @@ class Interactions(Navigator):
         return False
 
 
-    @Component._manage_driver()
-    def _like_feed_posts(self, count):
+    @Component._login_required
+    def like_feed_posts(self, count):
         LOGGER.debug('INSTACLIENT: like_feed_posts')
 
 
-    @Component._manage_driver()
-    def _like_post(self:'InstaClient', shortcode:str) -> Optional[Post]:
+    @Component._login_required
+    def like_post(self:'InstaClient', shortcode:str) -> Optional[Post]:
         # Nav Post Page
-        post:Post = self._scrape_post(shortcode=shortcode)
+        post:Post = self.get_post(shortcode=shortcode)
         if post and post.viewer_has_liked:
             return post
 
@@ -204,10 +204,10 @@ class Interactions(Navigator):
             return post
 
 
-    @Component._manage_driver()
-    def _unlike_post(self:'InstaClient', shortcode:str) -> Optional[Post]:
+    @Component._login_required
+    def unlike_post(self:'InstaClient', shortcode:str) -> Optional[Post]:
         # Nav Post Page
-        post:Post = self._scrape_post(shortcode=shortcode)
+        post:Post = self.get_post(shortcode=shortcode)
         if post and not post.viewer_has_liked:
             return post
 
@@ -225,8 +225,8 @@ class Interactions(Navigator):
             return None
 
 
-    @Component._manage_driver()
-    def _comment_on_post(self:'InstaClient', shortcode:str, text:str) -> bool:
+    @Component._login_required
+    def comment_post(self:'InstaClient', shortcode:str, text:str) -> bool:
         # Load Page
         self._nav_post_comments(shortcode)
 
